# Meltano: Your DataOps OS

[![pipeline status](https://gitlab.com/meltano/meltano/badges/master/pipeline.svg)](https://gitlab.com/meltano/meltano/commits/master)

[Meltano](https://meltano.com) is
[open source](https://gitlab.com/meltano/meltano),
[self-hosted](https://docs.meltano.com/guide/production),
[CLI-first](https://docs.meltano.com/reference/command-line-interface),
[debuggable](https://docs.meltano.com/reference/command-line-interface#debugging), and
[extensible](https://docs.meltano.com/concepts/plugins).

[Pipelines are code](https://docs.meltano.com/concepts/project),
ready to be version controlled,
[containerized](https://docs.meltano.com/guide/containerization), and
[deployed continuously](https://docs.meltano.com/guide/production#your-meltano-project).
Develop and test
[locally](https://docs.meltano.com/getting-started#install-meltano),
then
[deploy in production](https://docs.meltano.com/guide/production)
along with the built-in
[Airflow integration](https://docs.meltano.com/guide/production#airflow-orchestrator),
or inside your
[orchestrator of choice](https://docs.meltano.com/guide/production#running-pipelines).

Meltano [embraces](https://handbook.meltano.com/product/singer) the [Singer](https://www.singer.io/) standard and its community-maintained library of open source
[extractors](https://hub.meltano.com/extractors/) and
[loaders](https://hub.meltano.com/loaders/),
and leverages [dbt](https://www.getdbt.com) for [transformation](https://docs.meltano.com/guide/transformation).

## Documentation

Check out the ["Getting Started" guide](https://docs.meltano.com/getting-started)
or find the full documentation at <https://docs.meltano.com>.

## Contributing to Meltano

We welcome contributions and improvements, please see the [contribution guidelines](https://docs.meltano.com/contribute/)

## Responsible Disclosure Policy

Please refer to the [responsible disclosure policy](https://docs.meltano.com/the-project/responsible-disclosure) on our website.

## License

This code is distributed under the MIT license, see the [LICENSE](LICENSE) file.
